@@ -3,26 +3,31 @@ package WWW::Scraper::Wikipedia::ISO3166::Database::Import;
 use parent 'WWW::Scraper::Wikipedia::ISO3166::Database';
 use feature 'say';
 use strict;
-use utf8;
 use warnings;
 use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
 
 use Encode; # For decode().
 
-use Hash::FieldHash ':all';
-
 use HTML::TreeBuilder;
 
 use List::AllUtils 'first';
 use List::Compare;
 
+use Moo;
+
+use Types::Standard qw/HashRef Str/;
+
 use Unicode::CaseFold; # For fc().
 
-fieldhash my %code2 => 'code2';
+has code2 =>
+(
+	default  => sub{return ''},
+	is       => 'rw',
+	isa      => Str,
+	required => 0,
+);
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
 # ----------------------------------------------
 
@@ -176,16 +181,6 @@ sub get_table
 
 # -----------------------------------------------
 
-sub _init
-{
-	my($self, $arg) = @_;
-
-	return $self -> SUPER::_init($arg);
-
-} # End of _init.
-
-# -----------------------------------------------
-
 sub parse_country_code_page
 {
 	my($self)    = @_;
@@ -1866,7 +1861,7 @@ Delete the I<detail> key of the arrayref of hashrefs for the subcountry.
 
 =head2 save_countries($code3, $table)
 
-Save the I<countries> table, by combining the output of L<parse_country_code_page()> with the output of
+Save the I<countries> table, by combining the output of L</parse_country_code_page()> with the output of
 L</process_countries($table)>.
 
 =head2 save_subcountries($count, $table)
